@@ -41,6 +41,8 @@ class ObservableMixin(object):
         """
         Вызов action под наблюдением
         """
+        self._observer.configure()
+
         stack = stack[:]
         self._observer._prepare_for_listening(action, request, stack)
 
@@ -125,7 +127,7 @@ class Observer(object):
     # уровни детализации отладочного логировния
     LOG_NONE, LOG_WARNINGS, LOG_CALLS, LOG_MORE = 0, 1, 2, 3
 
-    class _BeforAfterPack:
+    class _BeforeAfterPack:
         """
         Обертка для списка слушателей, реализующая вызов before/after
         в соответствии с приоритетом, определяемым порякрм слушателей
@@ -188,6 +190,8 @@ class Observer(object):
         self._model_register = {}
         self._pack_instances_by_name = {}
 
+        self._is_configured = False
+
     def get(self, model_name):
         """
         Поиск экземпляра ActionPack для модели по имени её класса.
@@ -231,10 +235,18 @@ class Observer(object):
 
         return name
 
-    def _reconfigure(self):
+    def configure(self, force=False):
         """
-        Перестройка дерева сопоставления экшнов со слушателями
+        Построение дерева сопоставления экшнов со слушателями
+        Если observer был сконфигурирован ранее и в него ничего не добавили,
+        то построение выполнится, только если передан аргумент `force=True`
+
+        :param bool force: Форсировать конфигурирование
         """
+        # конфижим листенеры только понеобходимости
+        if self._is_configured and not force:
+            return
+
         self._action_listeners = {}
         # слушатели сортируются по приоритету
         listeners = [
@@ -253,6 +265,8 @@ class Observer(object):
                         '\n\tListener\t %r' % (name, listener))
             self._action_listeners[name] = action_listeners
 
+        self._is_configured = True
+
     def _populate_pack(self, pack):
         """
         Подписка зарегистрированных слушателей на pack.actions
@@ -301,7 +315,8 @@ class Observer(object):
                     'because this name registered for %r!'
                     % (name, action, self._actions[name]))
             self._actions[name] = action
-        self._reconfigure()
+
+        self._is_configured = False
 
     def subscribe(self, listener):
         """
@@ -326,7 +341,7 @@ class Observer(object):
             self.LOG_MORE,
             'Listener registered:\n\tListener %r' % listener)
 
-        self._reconfigure()
+        self._is_configured = False
 
         return listener
 
@@ -416,7 +431,7 @@ class Observer(object):
         # если подписчики есть, в стек паков добавляется "пак",
         # реализующий подписку на before/after
         if listeners:
-            stack.insert(0, self._BeforAfterPack(
+            stack.insert(0, self._BeforeAfterPack(
                 action, listeners,
                 # инжекция логирования
                 logger=lambda msg: self._log(self.LOG_CALLS, msg)
