@@ -5,10 +5,10 @@ Created on 23.07.2012
 """
 import datetime
 from functools import wraps
+from operator import attrgetter as _attrgetter
 
-from django.db import transaction
-from django.db.models.fields import FieldDoesNotExist
-from django.db.models.fields.related import RelatedField
+from django.db import transaction as _transaction
+from django.db.models.fields.related import RelatedField as _RelatedField
 
 
 #==============================================================================
@@ -187,19 +187,19 @@ class TransactionCM(object):
         self._catcher = catcher or self._default_catcher
 
     def __enter__(self):
-        transaction.enter_transaction_management(True, self._using)
-        return transaction
+        _transaction.enter_transaction_management(True, self._using)
+        return _transaction
 
     def __exit__(self, *args):
         result = self._catcher(*args)
         if result:
-            transaction.commit(self._using)
+            _transaction.commit(self._using)
         else:
-            transaction.rollback(self._using)
+            _transaction.rollback(self._using)
         return result
 
     @staticmethod
-    def _default_catcher(ex_type, ex_inst, traceback):
+    def _default_catcher(ex_type, *args):
         """
         Обработчик исключений, используемый по-умолчанию
         """
@@ -242,26 +242,26 @@ def extract_int_list(request, key):
     return map(int, filter(None, request.REQUEST.get(key, '').split(',')))
 
 
-def str_to_date(s):
+def str_to_date(raw_str):
     """
     Извлечение даты из строки
 
     >>> str_to_date('31.12.2012') == str_to_date('2012-12-31, Happy New Year')
     True
     """
-    if s:
-        s = s[:10]
-        s = s.replace('-', '.')
+    if raw_str:
+        raw_str = raw_str[:10]
+        raw_str = raw_str.replace('-', '.')
         try:
-            s = datetime.datetime.strptime(s, '%d.%m.%Y')
+            raw_str = datetime.datetime.strptime(raw_str, '%d.%m.%Y')
         except ValueError:
             try:
-                s = datetime.datetime.strptime(s, '%Y.%m.%d')
+                raw_str = datetime.datetime.strptime(raw_str, '%Y.%m.%d')
             except ValueError:
-                s = None
+                raw_str = None
     else:
-        s = None
-    return s
+        raw_str = None
+    return raw_str
 
 
 def extract_date(request, key, as_date=False):
@@ -357,9 +357,9 @@ def collect_overlaps(obj, queryset, attr_begin='begin', attr_end='end'):
         queryset = queryset.exclude(id=obj.id)
 
     result = []
-    for o in queryset.iterator():
-        bgn = getattr(o, attr_begin, None)
-        end = getattr(o, attr_end, None)
+    for item in queryset.iterator():
+        bgn = getattr(item, attr_begin, None)
+        end = getattr(item, attr_end, None)
         if bgn is None or end is None:
             raise ValueError(
                 u'Среди объектов выборки присутствуют некорректные!')
@@ -371,7 +371,7 @@ def collect_overlaps(obj, queryset, attr_begin='begin', attr_end='end'):
                 obj_bgn <= bgn <= obj_end,
                 obj_bgn <= end <= obj_end,
             )):
-                result.append(o)
+                result.append(item)
 
         try:
             add()
@@ -387,14 +387,14 @@ def collect_overlaps(obj, queryset, attr_begin='begin', attr_end='end'):
 #==============================================================================
 # istraversable - проверка на "обходимость"
 #==============================================================================
-def istraversable(x):
+def istraversable(obj):
     """
-    возвращает True, если объект :attr:`x` позволяет обход себя в цикле `for`
+    возвращает True, если объект :attr:`obj` позволяет обход себя в цикле `for`
     """
     return (
-        hasattr(x, '__iter__')
-        or hasattr(x, '__next__')
-        or hasattr(x, '__getitem__')
+        hasattr(obj, '__iter__')
+        or hasattr(obj, '__next__')
+        or hasattr(obj, '__getitem__')
     )
 
 
@@ -409,13 +409,13 @@ def cached_to(attr_name):
     :param attr_name: Куда кэшировать
     :type attr_name: str
     """
-    def wrapper(fn):
-        @wraps(fn)
+    def wrapper(func):
+        @wraps(func)
         def inner(self):
             if hasattr(self, attr_name):
                 result = getattr(self, attr_name)
             else:
-                result = fn(self)
+                result = func(self)
                 setattr(self, attr_name, result)
             return result
         return inner
@@ -425,58 +425,27 @@ def cached_to(attr_name):
 #==============================================================================
 # парсеры для декларации контекста
 #==============================================================================
-def int_or_zero(s):
+def int_or_zero(raw_str):
     """
     >>> int_or_zero('')
     0
     >>> int_or_zero('10')
     10
     """
-    return 0 if not s else int(s)
+    return 0 if not raw_str else int(raw_str)
 
-
-def int_or_none(s):
+def int_or_none(raw_str):
     """
     >>> int_or_none('')
     None
     >>> int_or_none('10')
     10
     """
-    return None if not s else int(s)
+    return None if not raw_str else int(raw_str)
 
-
-def int_list(s):
+def int_list(raw_str):
     """
     >>> int_list('10,20, 30')
     [10, 20, 30]
     """
-    return [int(i.strip()) for i in s.split(',')]
-
-
-def get_related_fields(model, fields):
-    """
-    >>> from django.contrib.auth.models import Permission
-    >>> get_related_fields(Permission, ["content_type", "name"])
-    ["content_type"]
-
-    :param model: Django Model
-    :type model: django.db.models.Model
-    :param fields: Path to extract foreign object attribute
-    :type fields: list
-    """
-    result = []
-    field_name = fields.pop(0)
-    if fields:
-        try:
-            field = model._meta.get_field(field_name)
-        except (FieldDoesNotExist, KeyError, AttributeError):
-            # KeyError - исключение в objectpack.ModelProxy
-            # FieldDoesNotExist - в django Model
-            # AttributeError - у модели может не быть меты или метода get_field
-            # в случае если это VirtualModel или любая иная фейковая модель
-            pass
-        else:
-            if isinstance(field, RelatedField):
-                result.append(field_name)
-                result.extend(get_related_fields(field.rel.to, fields))
-    return result
\ No newline at end of file
+    return [int(i.strip()) for i in raw_str.split(',')]
\ No newline at end of file
